@@ -17,6 +17,9 @@
 
 """Transport classes and utilities shared among Python Elastic client libraries"""
 
+import sys
+import warnings
+
 from ._version import __version__  # noqa
 from .connection import Connection, RequestsHttpConnection, Urllib3HttpConnection
 from .connection_pool import (
@@ -86,3 +89,12 @@ __all__ = [
     "UnprocessableEntityError",
     "Urllib3HttpConnection",
 ]
+
+# Python earlier than 3.6 is deprecated and will be removed in 8.0.0
+if sys.version_info < (3, 6):
+    warnings.warn(
+        "Support for Python 3.5 and earlier is deprecated and will be removed "
+        "in v8.0.0 (current instance is Python %d.%d)" % sys.version_info[:2],
+        category=DeprecationWarning,
+        stacklevel=2,
+    )
